@@ -22,10 +22,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <rarian-reg-utils.h>
+#define I_KNOW_RARIAN_0_8_IS_UNSTABLE
 #include <rarian.h>
-#include <rarian-info.h>
-#include <rarian-man.h>
 
 void
 print_section (RrnSect *sect, int depth)
@@ -52,19 +50,28 @@ print_section (RrnSect *sect, int depth)
 int
 for_each_cb (RrnReg *reg, void * user_data)
 {
-	RrnSect *sect;
+  RrnSect *sect;
+  char **cats;
     if (!reg) {
         printf ("Error: No reg passed in!\n");
         exit (6);
     }
     printf ("Document: %s\n", reg->name);
     printf ("-> %s\n", reg->uri);
-    printf ("-> ghelp:%s\n\n", reg->ghelp_name);
+    printf ("-> ghelp:%s\n", reg->ghelp_name);
+    cats = reg->categories;
+    if (cats && *cats)
+      printf ("Categories:\n");
+    while (cats && *cats) {
+      printf ("-> %s\n", *cats);
+      cats++;
+    }
+    printf ("\n");
 
-	sect = reg->children;
+    sect = reg->children;
     while (sect) {
-    	print_section (sect, 1);
-    	sect = sect->next;
+      print_section (sect, 1);
+      sect = sect->next;
     }
 
     return TRUE;
@@ -96,7 +103,7 @@ main(int argc, char *argv[])
   char **cats =  rrn_info_get_categories ();
   char **iter = cats;
   
-  /*  rrn_man_for_each ((RrnManForeachFunc) man_for_each, NULL);
+  rrn_man_for_each ((RrnManForeachFunc) man_for_each, NULL);
   
   while (iter && *iter) {
     printf ("Info category: %s\n", *iter);
@@ -104,12 +111,12 @@ main(int argc, char *argv[])
   }
 
   rrn_info_for_each ((RrnInfoForeachFunc) info_for_each, NULL);
-  */
+  
   rrn_for_each((RrnForeachFunc) for_each_cb, NULL);
 
   rrn_shutdown ();
-  /*  rrn_info_shutdown ();
+  rrn_info_shutdown ();
   rrn_man_shutdown ();
-  */
+  
   return 0;
 }
